# Parser for Talon files in Python

[![GitHub Workflow Status](https://github.com/wenkokke/py-tree-sitter-talon/actions/workflows/build.yml/badge.svg)](https://github.com/wenkokke/py-tree-sitter-talon/actions/workflows/build.yml) ![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/wenkokke/py-tree-sitter-talon) ![PyPI](https://img.shields.io/pypi/v/tree-sitter-talon)
